# ProjectDefConstraints

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**markers** | **str** | An environment marker used with the version constrain |
**name** | **str** | Name of the package that was constrained |
**version** | **str** | Version range specifier for the constrain |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

